#  Common setup

CURDIR=`pwd`
BASE=$CURDIR
SRCDIR=$CURDIR/srcs

NOBUILD=0
NOCLEAN=0

function usage
{
  CMD=`basename $0`
  echo $DESC
  echo "usage: $CMD <options>"
  echo "  options:"
  echo "     -base <dir>  Set dir for build (defaults to current dir)"
  echo "     -help	  Print this help info"
  echo "     -nobuild	  Do not build package"
  echo "     -noclean	  Do not delete build files"
  echo "     -source	  Dir containing source (defaults to ./srcs)"
  echo 
}
  
while [ $# -gt 0 ] ; do
  case $1 in 
    "-base" | "--base"       )
        BASE=$2; shift; shift ;;
    "-nobuild" | "--nobuild" ) 
    	NOBUILD=1; shift ;;
    "-noclean" | "--noclean" )
        NOCLEAN=1; shift ;;
    "-help" | "--help"	     ) 
        usage; exit ;;
    "-source" | "--source"   ) 
        SRCDIR=$2; shift; shift ;;
    -*                       )
      echo "Unrecognized option: $1"; exit ;;
    * )          
      OPTS="$OPTS $1" ; shift ;;
  esac
done

sys=`uname`

uname -a | grep x86_64 > /dev/null
if [ $? == 0 ]; then
    BITS64=64
else
    BITS64=
fi

case $sys in
  Sun*)		PLATFORM=sol
  		EXT=
		MAKE=gmake
  		;;
  MINGW*)	PLATFORM=nt
  		EXT=.exe
		MAKE=make
  		;;
  CYGWIN*)	PLATFORM=nt
  		EXT=.exe
		MAKE=make
  		;;
  Linux*)	PLATFORM=lin$BITS64
  		EXT=
		MAKE=make
  		;;
esac

BLDDIR=$BASE/build/${PLATFORM}
RELDIR=$BASE/release/${PLATFORM}

#  Extract Xilinx version info from sdk_version.h
VERSION=`grep "#define Xilinx_SDK_SoftwareVersion_macro " \
	 $SRCDIR/sdk_version.h | sed -e 's/^.*"\([^"]*\)"$/\1/'`
BUILD=`grep "#define Xilinx_SDK_SoftwareBuild_macro " \
       $SRCDIR/sdk_version.h | sed -e 's/^.*"\([^"]*\)"$/\1/'`
TODAY=`date +"%e %b %Y"`
XILINX_VERSION="$VERSION Build $BUILD $TODAY"
